/* one-dark theme for CodeMirror */
.cm-s-one-dark.CodeMirror {
    background-color: #282C34;
    color: #ABB2BF;
  }
  
  .cm-s-one-dark .CodeMirror-gutters {
    background-color: #282C34;
    border-right: 1px solid #3E4451;
  }
  
  .cm-s-one-dark .CodeMirror-linenumber {
    color: #6e7681;
  }
  
  .cm-s-one-dark .CodeMirror-cursor {
    border-left: 1px solid #ABB2BF;
  }
  
  .cm-s-one-dark .CodeMirror-selected {
    background: #3E4451;
  }
  
  /* Token Colors */
  .cm-s-one-dark .cm-comment {
    color: #7F848E;
    font-style: italic;
  }
  
  .cm-s-one-dark .cm-error {
    color: #e06c75;
    background-color: #1e0010;
  }
  
  .cm-s-one-dark .cm-keyword {
    color: #C678DD;
  }
  
  .cm-s-one-dark .cm-operator {
    color: #56B6C2;
    font-weight: bold;
  }
  
  .cm-s-one-dark .cm-literal {
    color: #d19a66;
  }
  
  .cm-s-one-dark .cm-variable {
    color: #e06c75;
  }
  
  .cm-s-one-dark .cm-punctuation {
    color: #ABB2BF;
  }
  
  .cm-s-one-dark .cm-number {
    color: #D19A66;
  }
  
  .cm-s-one-dark .cm-string {
    color: #98C379;
  }
  
  .cm-s-one-dark .cm-attribute {
    color: #E06C75;
  }
  
  .cm-s-one-dark .cm-builtin {
    color: #E5C07B;
  }
  
  .cm-s-one-dark .cm-variable-2 {
    color: #E06C75;
  }
  
  .cm-s-one-dark .cm-variable-3 {
    color: #E5C07B;
    font-weight: bold;
  }
  
  .cm-s-one-dark .cm-atom {
    color: #56B6C2;
    font-weight: bold;
  }
  
  .cm-s-one-dark .cm-def {
    color: #61AFEF;
    font-weight: bold;
  }
  
  .cm-s-one-dark .cm-tag {
    color: #E06C75;
  }
  
  .cm-s-one-dark .cm-string-2 {
    color: #98C379;
  }
  
  /* Generic Styling */
  .cm-s-one-dark .cm-em {
    font-style: italic;
  }
  
  .cm-s-one-dark .cm-strong {
    font-weight: bold;
  }
  
  .cm-s-one-dark .cm-header {
    color: #61AFEF;
    font-weight: bold;
  }
  
  .cm-s-one-dark .cm-quote {
    color: #7F848E;
    font-style: italic;
  }
  
  .cm-s-one-dark .cm-link {
    color: #61AFEF;
    text-decoration: underline;
  }