/* github-dark theme for CodeMirror */
.cm-s-github-dark.CodeMirror {
    background-color: #0d1117;
    color: #e6edf3;
  }
  
  .cm-s-github-dark .CodeMirror-gutters {
    background-color: #0d1117;
    border-right: 1px solid #30363d;
  }
  
  .cm-s-github-dark .CodeMirror-linenumber {
    color: #6e7681;
  }
  
  .cm-s-github-dark .CodeMirror-cursor {
    border-left: 1px solid #2f81f7;
  }
  
  .cm-s-github-dark .CodeMirror-selected {
    background: #6e768166;
  }
  
  /* Token Colors */
  .cm-s-github-dark .cm-comment {
    color: #8b949e;
    /* font-style: italic; */
  }
  
  .cm-s-github-dark .cm-error {
    color: #f85149;
  }
  
  .cm-s-github-dark .cm-keyword {
    color: #ff7b72;
  }
  
  .cm-s-github-dark .cm-operator {
    color: #ff7b72;
    font-weight: bold;
  }
  
  .cm-s-github-dark .cm-literal {
    color: #a5d6ff;
  }
  
  .cm-s-github-dark .cm-variable {
    color: #e6edf3;
  }
  
  .cm-s-github-dark .cm-punctuation {
    color: #e6edf3;
  }
  
  .cm-s-github-dark .cm-number {
    color: #a5d6ff;
  }
  
  .cm-s-github-dark .cm-string {
    color: #a5d6ff;
  }
  
  .cm-s-github-dark .cm-variable-2 {
    color: #e6edf3;
  }
  
  .cm-s-github-dark .cm-variable-3 {
    color: #f0883e;
    font-weight: bold;
  }
  
  .cm-s-github-dark .cm-atom {
    color: #79c0ff;
    font-weight: bold;
  }
  
  .cm-s-github-dark .cm-def {
    color: #d2a8ff;
    font-weight: bold;
  }
  
  .cm-s-github-dark .cm-tag {
    color: #7ee787;
  }
  
  .cm-s-github-dark .cm-string-2 {
    color: #a5d6ff;
  }
  
  /* Generic Styling */
  .cm-s-github-dark .cm-em {
    font-style: italic;
  }
  
  .cm-s-github-dark .cm-strong {
    font-weight: bold;
  }
  
  .cm-s-github-dark .cm-header {
    color: #79c0ff;
    font-weight: bold;
  }
  
  .cm-s-github-dark .cm-quote {
    color: #8b949e;
    font-style: italic;
  }
  
  .cm-s-github-dark .cm-link {
    color: #79c0ff;
    text-decoration: underline;
  }