/* github-light theme for CodeMirror */
.cm-s-github-light.CodeMirror {
  background-color: #ffffff;
  color: #24292f;
}

.cm-s-github-light .CodeMirror-gutters {
  background-color: #ffffff;
  border-right: 1px solid #d1d5da;
}

.cm-s-github-light .CodeMirror-linenumber {
  color: #6e7781;
}

.cm-s-github-light .CodeMirror-cursor {
  border-left: 1px solid #24292f;
}

.cm-s-github-light .CodeMirror-selected {
  background: #0969da4a;
}

/* Token Colors */
.cm-s-github-light .cm-comment {
  color: #6e7781;
  /* font-style: italic; */
}

.cm-s-github-light .cm-error {
  color: #cf222e;
}

.cm-s-github-light .cm-keyword {
  color: #cf222e;
}

.cm-s-github-light .cm-operator {
  color: #116329;
  font-weight: bold;
}

.cm-s-github-light .cm-literal {
  color: #953800;
}

.cm-s-github-light .cm-variable {
  color: #8250df;
}

.cm-s-github-light .cm-punctuation {
  color: #24292f;
}

.cm-s-github-light .cm-number {
  color: #953800;
}

.cm-s-github-light .cm-string {
  color: #0550ae;
}

.cm-s-github-light .cm-attribute {
  color: #953800;
}

.cm-s-github-light .cm-builtin {
  color: #953800;
}

.cm-s-github-light .cm-variable-2 {
  color: #116329;
}

.cm-s-github-light .cm-variable-3 {
  color: #0550ae;
  font-weight: bold;
}

.cm-s-github-light .cm-atom {
  color: #0550ae;
  font-weight: bold;
}

.cm-s-github-light .cm-def {
  color: #0550ae;
  /* font-weight: bold; */
}

.cm-s-github-light .cm-tag {
  color: #116329;
}

.cm-s-github-light .cm-string-2 {
  color: #0550ae;
}

/* Generic Styling */
.cm-s-github-light .cm-em {
  font-style: italic;
}

.cm-s-github-light .cm-strong {
  font-weight: bold;
}

.cm-s-github-light .cm-header {
  color: #0550ae;
  font-weight: bold;
}

.cm-s-github-light .cm-quote {
  color: #6e7781;
  font-style: italic;
}

.cm-s-github-light .cm-link {
  color: #116329;
  text-decoration: underline;
}