/* General styles */
.cm-s-github-dark-high-contrast.CodeMirror {
    background-color: #0d1117;
    color: #C9D1D9;
  }
  
  /* Gutter styles */
  .cm-s-github-dark-high-contrast .CodeMirror-gutters {
    background: #0d1117;
    border-right: 1px solid #C9D1D9;
  }
  
  .cm-s-github-dark-high-contrast .CodeMirror-linenumber {
    color: #6e7781;
  }
  
  .cm-s-github-dark-high-contrast .CodeMirror-cursor {
    border-left: 1px solid #C9D1D9;
  }
  
  /* Highlighted line */
  .cm-s-github-dark-high-contrast .CodeMirror-activeline-background {
    background: #58a6ff70;
  }
  
  /* Selection */
  .cm-s-github-dark-high-contrast .CodeMirror-selected {
    background: #58a6ff70;
  }
  
  /* Token styles */
  .cm-s-github-dark-high-contrast .cm-comment {
    color: #d9dee3;
  }
  
  .cm-s-github-dark-high-contrast .cm-error {
    color: #ff9492;
  }
  
  .cm-s-github-dark-high-contrast .cm-keyword {
    color: #ff9492;
  }
  
  .cm-s-github-dark-high-contrast .cm-atom {
    color: #ffb757;
  }
  
  .cm-s-github-dark-high-contrast .cm-number {
    color: #ffb757;
  }
  
  .cm-s-github-dark-high-contrast .cm-def {
    color: #91cbff;
  }
  
  .cm-s-github-dark-high-contrast .cm-variable {
    color: #dbb7ff;
  }
  
  .cm-s-github-dark-high-contrast .cm-variable-2 {
    color: #ffb757;
  }
  
  .cm-s-github-dark-high-contrast .cm-variable-3 {
    color: #ffb757;
  }
  
  .cm-s-github-dark-high-contrast .cm-property {
    color: #91cbff;
  }
  
  .cm-s-github-dark-high-contrast .cm-operator {
    color: #72f088;
  }
  
  .cm-s-github-dark-high-contrast .cm-punctuation {
    color: #C9D1D9;
  }
  
  .cm-s-github-dark-high-contrast .cm-string {
    color: #91cbff;
  }
  
  .cm-s-github-dark-high-contrast .cm-string-2 {
    color: #91cbff;
  }
  
  .cm-s-github-dark-high-contrast .cm-meta {
    color: #ffb757;
  }
  
  .cm-s-github-dark-high-contrast .cm-qualifier {
    color: #ff9492;
  }
  
  .cm-s-github-dark-high-contrast .cm-builtin {
    color: #ffb757;
  }
  
  .cm-s-github-dark-high-contrast .cm-bracket {
    color: #C9D1D9;
  }
  
  .cm-s-github-dark-high-contrast .cm-tag {
    color: #72f088;
  }
  
  .cm-s-github-dark-high-contrast .cm-attribute {
    color: #ffb757;
  }
  
  .cm-s-github-dark-high-contrast .cm-hr {
    color: #C9D1D9;
  }
  
  .cm-s-github-dark-high-contrast .cm-link {
    color: #91cbff;
  }
  
  /* Emphasis and Strong */
  .cm-s-github-dark-high-contrast .cm-em {
    font-style: italic;
  }
  
  .cm-s-github-dark-high-contrast .cm-strong {
    font-weight: bold;
  }
  
  /* Generic */
  .cm-s-github-dark-high-contrast .cm-error {
    color: #ff9492;
  }
  
  .cm-s-github-dark-high-contrast .cm-quote {
    color: #d9dee3;
  }
  
  /* Specific to f-strings in Python */
  .cm-s-github-dark-high-contrast .cm-string-2 .cm-operator {
    color: #C9D1D9; /* Ensure the operator in f-strings has the correct color */
  }