
.cm-s-github-dark-default.CodeMirror {
    background-color: #0d1117;
    color: #e6edf3;
}

.cm-s-github-dark-default .CodeMirror-gutters {
    background-color: #0d1117;
    border-right: 1px solid #30363d;
}


.cm-s-github-dark-default .CodeMirror-linenumber {
    color: #6e7681;
}


.cm-s-github-dark-default .CodeMirror-selected {
    background: #6e768166;
}



/* GitHub Dark Default Theme for CodeMirror */
.cm-s-github-dark-default .cm-keyword { color: #f97583; }
.cm-s-github-dark-default .cm-comment { color: #6a737d; }
.cm-s-github-dark-default .cm-string { color: #9ecbff; }
.cm-s-github-dark-default .cm-number { color: #79b8ff; }
.cm-s-github-dark-default .cm-def { color: #b392f0; } /* Functions */
.cm-s-github-dark-default .cm-variable { color: #e36209; }
.cm-s-github-dark-default .cm-operator { color: #f97583; }
.cm-s-github-dark-default .cm-meta { color: #6a737d; }
.cm-s-github-dark-default .cm-atom { color: #79b8ff; }
.cm-s-github-dark-default .cm-tag { color: #85e89d; }
.cm-s-github-dark-default .cm-attribute { color: #b392f0; }
.cm-s-github-dark-default .cm-qualifier { color: #f97583; }
.cm-s-github-dark-default .cm-builtin { color: #e36209; }
.cm-s-github-dark-default .cm-bracket { color: #f97583; }
.cm-s-github-dark-default .cm-link { color: #9ecbff; }
.cm-s-github-dark-default .cm-error { color: #f97583; }