/* github-light-default.css */

.cm-s-github-light-default.CodeMirror {
    background-color: #ffffff;
    color: #24292e;
  }
  
  /* Set the default font and line height */
  .cm-s-github-light-default .CodeMirror-lines {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji";
    line-height: 1.5;
  }
  
  /* Caret color */
  .cm-s-github-light-default .CodeMirror-cursor {
    border-left: 1px solid #24292e;
  }
  
  /* Selection */
  .cm-s-github-light-default .CodeMirror-selected {
    background-color: #0366d6;
    color: #ffffff;
  }
  
  /* Line numbers */
  .cm-s-github-light-default .CodeMirror-gutters {
    background-color: #f6f8fa;
    border-right: 1px solid #e1e4e8;
    color: #959da5;
  }
  
  .cm-s-github-light-default .CodeMirror-linenumber {
    color: #959da5;
  }
  
  /* Matching brackets */
  .cm-s-github-light-default .CodeMirror-matchingbracket {
    text-decoration: underline;
    color: #22863a;
  }
  
  /* Comments */
  .cm-s-github-light-default .cm-comment {
    color: #6a737d;
    font-style: italic;
  }
  
  /* Keywords */
  .cm-s-github-light-default .cm-keyword {
    color: #d73a49;
  }
  
  /* Strings */
  .cm-s-github-light-default .cm-string {
    color: #032f62;
  }
  
  /* Numbers */
  .cm-s-github-light-default .cm-number {
    color: #005cc5;
  }
  
  /* Functions */
  .cm-s-github-light-default .cm-def {
    color: #6f42c1;
  }
  
  /* Variables */
  .cm-s-github-light-default .cm-variable {
    color: #000000;
  }
  
  /* Tags */
  .cm-s-github-light-default .cm-tag {
    color: #22863a;
  }
  
  /* Attributes */
  .cm-s-github-light-default .cm-attribute {
    color: #6f42c1;
  }
  
  /* Property names */
  .cm-s-github-light-default .cm-property {
    color: #005cc5;
  }
  
/* Error text */
.cm-s-github-light-default .cm-error {
color: #b31d28;
background-color: #fef2f2;
}
  

  /* Built-in functions */
.cm-s-github-light-default .cm-builtin {
    color: #6f42c1; /* This is the purple color used in GitHub Light for built-ins */
}

/* f-string specifier 'f' */
.cm-s-github-light-default .cm-string.cm-format {
    color: #d73a49; /* Red color for the 'f' in f-strings */
  }
  
  /* Curly brackets in f-strings */
  .cm-s-github-light-default .cm-bracket {
    color: #e36209; /* Orange color for curly brackets */
  }
